local player = {}
	player.hitBoxes = {}
		player.hitBoxes.bigRectangle = {}
			player.hitBoxes.bigRectangle.x = 0
			player.hitBoxes.bigRectangle.y = 0
			player.hitBoxes.bigRectangle.w = 50
			player.hitBoxes.bigRectangle.h = 100
		player.hitBoxes.smallRectangle = {}
			player.hitBoxes.smallRectangle.x = 0
			player.hitBoxes.smallRectangle.y = 55
			player.hitBoxes.smallRectangle.w = 30
			player.hitBoxes.smallRectangle.h = 10
		player.hitBoxes.leftCircle = {}
			player.hitBoxes.leftCircle.x = -15
			player.hitBoxes.leftCircle.y = 55
			player.hitBoxes.leftCircle.r = 10
		player.hitBoxes.rightCircle = {}
			player.hitBoxes.rightCircle.x = 15
			player.hitBoxes.rightCircle.y = 55
			player.hitBoxes.rightCircle.r = 10
	player.walkSpeed = 2400
	player.jumpForce = 1200
	player.mass = 1000
	player.sprite = nil
	player.color = {255,255,255}
	player.state = "flying like a boss"
	player.keys = {}
		player.keys.jump = "w"
		player.keys.left = "a"
		player.keys.down = "s"
		player.keys.right = "d"

function player:spawn()
	local new = table.copy(self)
	--physics
	new.body = love.physics.newBody(world,0,0,"dynamic")
	new.body:setFixedRotation(true)
	
	--hitboxes
	new.shape = {}
		new.shape.bigRectangle = love.physics.newRectangleShape(self.hitBoxes.bigRectangle.x,self.hitBoxes.bigRectangle.y,self.hitBoxes.bigRectangle.w,self.hitBoxes.bigRectangle.h,0)
		new.shape.smallRectangle = love.physics.newRectangleShape(self.hitBoxes.smallRectangle.x,self.hitBoxes.smallRectangle.y,self.hitBoxes.smallRectangle.w,self.hitBoxes.smallRectangle.h,0)
		new.shape.leftCircle = love.physics.newCircleShape(self.hitBoxes.leftCircle.x, self.hitBoxes.leftCircle.y, self.hitBoxes.leftCircle.r)
		new.shape.rightCircle = love.physics.newCircleShape(self.hitBoxes.rightCircle.x, self.hitBoxes.rightCircle.y, self.hitBoxes.rightCircle.r)
	
	new.fixture = {}
		new.fixture[1] = love.physics.newFixture(new.body,new.shape.bigRectangle)
		new.fixture[2] = love.physics.newFixture(new.body,new.shape.smallRectangle)
		new.fixture[3] = love.physics.newFixture(new.body,new.shape.leftCircle)
		new.fixture[4] = love.physics.newFixture(new.body,new.shape.rightCircle)
		
	--friction	
	--for i,v in ipairs(new.fixture) do v:setFriction(0.5) end
	
	--new.fixture:setFriction(0.5)
	
	setmetatable(new,{__index = self})
	return new
end
		
function player:draw()
	love.graphics.setColor(self.color)
	love.graphics.setLineWidth(3)
	
	love.graphics.polygon("line",self.body:getWorldPoints(self.shape.bigRectangle:getPoints()))
	love.graphics.polygon("line",self.body:getWorldPoints(self.shape.smallRectangle:getPoints()))
	local x,y = self.body:getWorldPoints(self.shape.leftCircle:getPoint())
	love.graphics.circle("line",x,y,self.shape.leftCircle:getRadius(),self.shape.leftCircle:getRadius()*3)
	x,y = self.body:getWorldPoints(self.shape.rightCircle:getPoint())
	love.graphics.circle("line",x,y,self.shape.rightCircle:getRadius(),self.shape.rightCircle:getRadius()*3)
	
end

function player:update(dt)
	--controlcheck returns either -1,0 or 1 depending on walk direction
	local movement = self:controlCheck()
	if movement ~= 0 then
		--self.fixture:setFriction(0)
		self.body:applyForce(self.walkSpeed * movement,0)
	else
		--self.fixture:setFriction(10)
	end
end

function player:controlCheck(dt)
	local movement = 0
	if love.keyboard.isDown(self.keys.left) then movement = movement - 1 end
	if love.keyboard.isDown(self.keys.right) then movement = movement + 1 end
	
	return movement
end

function player:jumpCheck(key)
	if key == self.keys.jump then
		self:jump()
	end
end

function player:jump()
	self.body:applyLinearImpulse(0,-self.jumpForce)
end

return player