love.window.setMode(0,0,{fullscreen=true})

local Screen = {}
	--default size
	Screen.w = 1920
	Screen.h = 1080
	--monitor size
	Screen.monitor = {}
		Screen.monitor.w = love.graphics.getWidth()
		Screen.monitor.h = love.graphics.getHeight()
	Screen.draw = {}
		--draw area scale
		Screen.draw.scale = 1
		--draw area offset
		Screen.draw.x = 0
		Screen.draw.y = 0
	Screen.shake = {}
		Screen.shake.xNoise = 0 --x value for the noise
		Screen.shake.yNoise = 0 --y value for the noise
		Screen.shake.x = 0 --current camera x offset
		Screen.shake.y = 0 --current camera y offset
		Screen.shake.strenght = 0 --maximum distance from distance
		Screen.shake.reduceSpeed = 0 --how fast the strenght is reduced
		Screen.shake.violence = 1 --how fast the noise value changes
	Screen.canvas = love.graphics.newCanvas(Screen.w,Screen.h)
	
--run this function to resize the window		
function Screen:resize(w,h,fullscreen,vsync)
	--making sure screen isn't set bigger than the monitor!
	w,h = math.min(w,self.monitor.w),math.min(h,self.monitor.h)
	--setting window size
	love.window.setMode(w,h,{resizable = true, fullscreen = fullscreen, vsync = vsync})
	self.draw.scale = math.min(w/self.w,h/self.h)
	self.draw.x = -(self.w - w * 1/self.draw.scale) / 2
	self.draw.y = -(self.h - h * 1/self.draw.scale) / 2
end

function Screen:stretch(w,h)
	self.draw.scale = math.min(w/self.w,h/self.h)
	self.draw.x = -(self.w - w * 1/self.draw.scale) / 2
	self.draw.y = -(self.h - h * 1/self.draw.scale) / 2
end

--function to set screenshake
function Screen:setShake(strenght,timer,violence)
	--values for the noise
	self.shake.xNoise = love.math.random(1,100)
	self.shake.yNoise = love.math.random(1,100)
	
	self.shake.violence = violence or 1
	
	self.shake.strenght = strenght
	self.shake.reduceSpeed = strenght / timer
end

--function to update screenshake
function Screen:updateShake(dt)
	self.shake.xNoise = self.shake.xNoise + dt * self.shake.violence
	self.shake.yNoise = self.shake.yNoise + dt * self.shake.violence
	self.shake.strenght = math.max(self.shake.strenght - self.shake.reduceSpeed,0) 
	
	self.shake.x = math.floor((love.math.noise(self.shake.xNoise)-0.5) * 2 * self.shake.strenght)
	self.shake.y = math.floor((love.math.noise(self.shake.yNoise)-0.5) * 2 * self.shake.strenght)
end

function Screen:set()
	love.graphics.push()
	love.graphics.scale(self.draw.scale,self.draw.scale)
	love.graphics.translate(self.draw.x+self.shake.x,self.draw.y+self.shake.y)
end

function Screen:unset()
	love.graphics.pop()
end

return Screen